@@ -39,17 +39,12 @@ impl FromStr for BundleFormat {
 impl ValueEnum for BundleFormat {
   fn value_variants<'a>() -> &'a [Self] {
     static VARIANTS: OnceLock<Vec<BundleFormat>> = OnceLock::new();
-    VARIANTS.get_or_init(|| {
-      PackageType::all()
-        .iter()
-        .filter(|t| **t != PackageType::Updater)
-        .map(|t| Self(*t))
-        .collect()
-    })
+    VARIANTS.get_or_init(|| PackageType::all().iter().map(|t| Self(*t)).collect())
   }
 
   fn to_possible_value(&self) -> Option<PossibleValue> {
-    Some(PossibleValue::new(self.0.short_name()))
+    let hide = self.0 == PackageType::Updater;
+    Some(PossibleValue::new(self.0.short_name()).hide(hide))
   }
 }
 
@@ -63,13 +58,17 @@ pub struct Options {
   #[clap(short, long)]
   pub debug: bool,
   /// Space or comma separated list of bundles to package.
-  ///
-  /// Note that the `updater` bundle is not automatically added so you must specify it if the updater is enabled.
   #[clap(short, long, action = ArgAction::Append, num_args(0..), value_delimiter = ',')]
   pub bundles: Option<Vec<BundleFormat>>,
-  /// JSON string or path to JSON file to merge with tauri.conf.json
+  /// JSON strings or path to JSON files to merge with the default configuration file
+  ///
+  /// Configurations are merged in the order they are provided, which means a particular value overwrites previous values when a config key-value pair conflicts.
+  ///
+  /// Note that a platform-specific file is looked up and merged with the default file by default
+  /// (tauri.macos.conf.json, tauri.linux.conf.json, tauri.windows.conf.json, tauri.android.conf.json and tauri.ios.conf.json)
+  /// but you can use this for more specific use cases such as different build flavors.
   #[clap(short, long)]
-  pub config: Option<ConfigValue>,
+  pub config: Vec<ConfigValue>,
   /// Space or comma separated list of features, should be the same features passed to `tauri build` if any.
   #[clap(short, long, action = ArgAction::Append, num_args(0..))]
   pub features: Option<Vec<String>>,
@@ -109,7 +108,10 @@ pub fn command(options: Options, verbosity: u8) -> crate::Result<()> {
     .map(Target::from_triple)
     .unwrap_or_else(Target::current);
 
-  let config = get_config(target, options.config.as_ref().map(|c| &c.0))?;
+  let config = get_config(
+    target,
+    &options.config.iter().map(|c| &c.0).collect::<Vec<_>>(),
+  )?;
 
   let interface = AppInterface::new(
     config.lock().unwrap().as_ref().unwrap(),
