@@ -23,7 +23,9 @@ use crate::{
 use super::{CallbackFn, InvokeError, InvokeResponseBody, IpcResponse, Request, Response};
 
 pub const IPC_PAYLOAD_PREFIX: &str = "__CHANNEL__:";
+// TODO: Change this to `channel` in v3
 pub const CHANNEL_PLUGIN_NAME: &str = "__TAURI_CHANNEL__";
+// TODO: Change this to `plugin:channel|fetch` in v3
 pub const FETCH_CHANNEL_DATA_COMMAND: &str = "plugin:__TAURI_CHANNEL__|fetch";
 pub(crate) const CHANNEL_ID_HEADER_NAME: &str = "Tauri-Channel-Id";
 
@@ -35,7 +37,6 @@ static CHANNEL_DATA_COUNTER: AtomicU32 = AtomicU32::new(0);
 pub struct ChannelDataIpcQueue(pub(crate) Arc<Mutex<HashMap<u32, InvokeResponseBody>>>);
 
 /// An IPC channel.
-#[derive(Clone)]
 pub struct Channel<TSend = InvokeResponseBody> {
   id: u32,
   on_message: Arc<dyn Fn(InvokeResponseBody) -> crate::Result<()> + Send + Sync>,
@@ -49,6 +50,16 @@ const _: () = {
   struct Channel<TSend>(std::marker::PhantomData<TSend>);
 };
 
+impl<TSend> Clone for Channel<TSend> {
+  fn clone(&self) -> Self {
+    Self {
+      id: self.id,
+      on_message: self.on_message.clone(),
+      phantom: Default::default(),
+    }
+  }
+}
+
 impl<TSend> Serialize for Channel<TSend> {
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where
@@ -204,7 +215,7 @@ impl<TSend> Channel<TSend> {
   }
 }
 
-impl<'de, R: Runtime, TSend: Clone> CommandArg<'de, R> for Channel<TSend> {
+impl<'de, R: Runtime, TSend> CommandArg<'de, R> for Channel<TSend> {
   /// Grabs the [`Webview`] from the [`CommandItem`] and returns the associated [`Channel`].
   fn from_command(command: CommandItem<'de, R>) -> Result<Self, InvokeError> {
     let name = command.name;
@@ -245,6 +256,9 @@ fn fetch(
 
 pub fn plugin<R: Runtime>() -> TauriPlugin<R> {
   PluginBuilder::new(CHANNEL_PLUGIN_NAME)
-    .invoke_handler(crate::generate_handler![fetch])
+    .invoke_handler(crate::generate_handler![
+      #![plugin(__TAURI_CHANNEL__)]
+      fetch
+    ])
     .build()
 }
