@@ -45,8 +45,6 @@ pub fn get<R: Runtime>(manager: Arc<AppManager<R>>) -> UriSchemeProtocolHandler
     )
     .entered();
 
-    let manager = manager.clone();
-
     let respond = move |mut response: http::Response<Cow<'static, [u8]>>| {
       response
         .headers_mut()
@@ -113,7 +111,7 @@ pub fn get<R: Runtime>(manager: Arc<AppManager<R>>) -> UriSchemeProtocolHandler
 
                   let (mut response, mime_type) = match response {
                     InvokeResponse::Ok(InvokeResponseBody::Json(v)) => (
-                      http::Response::new(v.as_bytes().to_vec().into()),
+                      http::Response::new(v.into_bytes().into()),
                       mime::APPLICATION_JSON,
                     ),
                     InvokeResponse::Ok(InvokeResponseBody::Raw(v)) => (
@@ -147,7 +145,7 @@ pub fn get<R: Runtime>(manager: Arc<AppManager<R>>) -> UriSchemeProtocolHandler
                 http::Response::builder()
                   .status(StatusCode::INTERNAL_SERVER_ERROR)
                   .header(CONTENT_TYPE, mime::TEXT_PLAIN.essence_str())
-                  .body(e.as_bytes().to_vec().into())
+                  .body(e.into_bytes().into())
                   .unwrap(),
               );
             }
@@ -157,12 +155,7 @@ pub fn get<R: Runtime>(manager: Arc<AppManager<R>>) -> UriSchemeProtocolHandler
             http::Response::builder()
               .status(StatusCode::INTERNAL_SERVER_ERROR)
               .header(CONTENT_TYPE, mime::TEXT_PLAIN.essence_str())
-              .body(
-                "failed to acquire webview reference"
-                  .as_bytes()
-                  .to_vec()
-                  .into(),
-              )
+              .body("failed to acquire webview reference".as_bytes().into())
               .unwrap(),
           );
         }
@@ -177,12 +170,7 @@ pub fn get<R: Runtime>(manager: Arc<AppManager<R>>) -> UriSchemeProtocolHandler
       }
 
       _ => {
-        let mut r = http::Response::new(
-          "only POST and OPTIONS are allowed"
-            .as_bytes()
-            .to_vec()
-            .into(),
-        );
+        let mut r = http::Response::new("only POST and OPTIONS are allowed".as_bytes().into());
         *r.status_mut() = StatusCode::METHOD_NOT_ALLOWED;
         r.headers_mut().insert(
           CONTENT_TYPE,
@@ -414,8 +402,8 @@ fn handle_ipc_message<R: Runtime>(request: Request<String>, manager: &AppManager
                     error,
                   );
                 } else {
-                  let _ = Channel::from_callback_fn(webview, callback)
-                    .send(InvokeResponseBody::Raw(v.clone()));
+                  let _ =
+                    Channel::from_callback_fn(webview, callback).send(InvokeResponseBody::Raw(v));
                 }
               }
               InvokeResponse::Err(e) => responder_eval(
