@@ -145,7 +145,8 @@ pub fn run_app<R: Runtime, F: FnOnce(&App<R>) + Send + 'static>(
     .invoke_handler(tauri::generate_handler![
       cmd::log_operation,
       cmd::perform_request,
-      cmd::echo
+      cmd::echo,
+      cmd::spam,
     ])
     .build(tauri::tauri_build_context!())
     .expect("error while building tauri application");
